unit fonctions_manibx;

{$IFDEF FPC}
{$MODE Delphi}
{$ENDIF}

interface

uses
  Classes, SysUtils,
  {$IFDEF VERSIONS}
  fonctions_version,
  {$ENDIF}
  u_multidata,
  LazFileUtils,
  DB;


{$IFDEF VERSIONS}
const
      gver_fonctions_manibx : T_Version = ( Component : 'IBX Manframes package.' ;
                                         FileUnit : 'fonctions_ibx' ;
                        		 Owner : 'Matthieu Giroux' ;
                        		 Comment : 'Just add the package.' ;
                        		 BugsStory   : 'Version 1.0.2.0 : Putting a lot in Extended.' +#10
                                                     + 'Version 1.0.1.0 : Upgrading for XML Frames.' +#10
                                                     + 'Version 1.0.0.1 : Testing IBX.' +#10
                                                     + 'Version 1.0.0.0 : IBX Version.';
                        		 UnitType : 1 ;
                        		 Major : 1 ; Minor : 0 ; Release : 2 ; Build : 0 );
{$ENDIF}

procedure p_CreateIBXconnection ( const AOwner : TComponent ; var adtt_DatasetType : TDatasetType ; var AQuery : TDataset; var AConnection : TComponent );
type

{ TDM_IBX }

 TDM_IBX = class ( TDataModule )
       public
         constructor Create(AOwner: TComponent);
       //  procedure IBXDatasetPost ( ADataset : TDataSet );
     End;

 var GDM_IBX : TDM_IBX=nil;

implementation

uses IBQuery,
     IBIntf,
     fonctions_file,
     fonctions_ini,
     fonctions_db,
     {$IFDEF WINDOWS}
     fonctions_string,
     {$IFDEF FPC}
     unite_messages,
     {$ELSE}
     unite_messages_delphi,
     {$ENDIF}
     {$ENDIF}
     fonctions_dialogs,
     fonctions_system,
     IBUpdateSQL,
     IBServices,
     IBDatabase,
     FileUtil,
     fonctions_dbobjects,
     fonctions_manbase,
     fonctions_startibx,
     fonctions_createsql;


procedure p_CreateIBXconnection ( const AOwner : TComponent ; var adtt_DatasetType : TDatasetType ; var AQuery : TDataset; var AConnection : TComponent );
Begin
  adtt_DatasetType := dtIBX;
  AConnection :=TIBDataBase.Create(AOwner);
  with AConnection as TIBDataBase do
   Begin
    Params.Add('lc_ctype='+Gs_Charset_ibx);
    LoginPrompt:=False;
    AllowStreamedConnected:=True;
    DefaultTransaction := TIBTransaction.Create ( AOwner );
    with DefaultTransaction do
     Begin
      DefaultDatabase := AConnection as TIBDataBase;
      DefaultAction   := TACommit;
     End;
   End;
  if GDM_IBX = nil Then
    GDM_IBX:=TDM_IBX.Create(nil);
  AQuery := TIBQuery.Create(AOwner);
  with AQuery as TIBQuery do
     Begin
      Database := AConnection as TIBDataBase;
      UpdateObject:=TIBUpdateSQL.Create(AOwner);
//      AfterPost:=GDM_IBX.IBXDatasetPost;
     end;
end;



{ TDM_IBX }

constructor TDM_IBX.Create(AOwner: TComponent);
begin
  if not ( csDesigning in ComponentState ) Then
    Try
      GlobalNameSpace.BeginWrite;
      {$IFDEF FPC}
      CreateNew(AOwner, 0 );
      {$ELSE}
      CreateNew(AOwner);
      {$ENDIF}
      //ModuleCreate;
      DoCreate;
      GDM_IBX := Self ;

    Finally
      GlobalNameSpace.EndWrite;
    End
  Else
   inherited ;
end;

{ database creating function }
function fs_CreateIBXAlterBeginSQL :String;
Begin
  Result := 'SET SQL DIALECT 3;' + #10+ 'SET NAMES ' + Gs_Charset_ibx +';'+ #10;
end;

{ database creating function }
function fs_CreateIBXDatabase  ( const as_base, as_user, as_password, as_host : String ):String;
Begin
  Result := 'CREATE DATABASE '''+as_base+''' USER '''+as_user+''' PASSWORD '''+as_password+''' PAGE_SIZE 16384 DEFAULT CHARACTER SET '+Gs_Charset_ibx+';'+#10
          + 'CONNECT '''+as_base+''' USER '''+as_user+''' PASSWORD '''+as_password+''';'+#10;
End;

procedure p_saveFile ( const as_file : String ; const as_InsideFile : {$IFDEF DELPHI_9_UP} WideString {$ELSE} String{$ENDIF}  );
var lh_handleFile : THandle;
Begin
  if FileExistsUTF8(as_File) Then DeleteFileUTF8(as_File);
  lh_handleFile := FileCreateUTF8(as_File);
  try
    FileWriteln(lh_handleFile,as_InsideFile);
  finally
    FileClose(lh_handleFile);
  end;

end;

procedure p_ExecuteSQLCommand ( const as_SQL : {$IFDEF DELPHI_9_UP} WideString {$ELSE} String{$ENDIF}  );
var ls_exe : String;
Begin
  p_saveFile (fs_GetIniDir+'sql-firebird'+CST_EXTENSION_SQL_FILE,as_SQL);

  {$IFDEF WINDOWS}
  ls_exe := fs_GetFirebirdExeorLib(CST_FBISQL,CST_FBISQL_SUB);
  if not FileExistsUTF8(ls_exe) Then
    Begin
     MyShowMessage(fs_RemplaceMsg(GS_EXE_DO_NOT_EXISTS_EXITING,[ls_exe]));
     halt;
    end;
  ls_exe := fs_ExecuteProcess(ls_exe, ' -i '''+ fs_GetIniDir+'sql-firebird'+CST_EXTENSION_SQL_FILE
                           +''' -s 3');
  {$ELSE}
  ls_exe := fs_ExecuteProcess(CST_FBISQL, ' -i '''+ fs_GetIniDir+'sql-firebird'+CST_EXTENSION_SQL_FILE
                            +'''  -s 3');
  {$ENDIF}
  if ls_exe > '' Then
    MyShowMessage('Erreur'+#10+ls_exe);
End ;

{ database creating function }
function fs_CreateIBXAlterEndSQL ( const as_base, as_user, as_password, as_host : String ):String;
Begin
  Result := 'COMMIT;'+ #10;
end;

initialization
 ge_onInitConnection    := TCreateConnection ( p_CreateIBXconnection );
 ge_OnBeginCreateAlter  := TOnGetSQL( fs_CreateIBXAlterBeginSQL);
 ge_OnEndCreate         := TOnSetDatabase( fs_CreateIBXAlterEndSQL);
 ge_OnCreateDatabase    := TOnSetDatabase( fs_CreateIBXDatabase);
 ge_OnExecuteCommand    := TOnExecuteCommand( p_ExecuteSQLCommand );
 gbm_DatabaseToGenerate := bmFirebird ;
 {$IFDEF VERSIONS}
 p_ConcatVersion ( gver_fonctions_manibx );
 {$ENDIF}
finalization
 FreeAndNil(GDM_IBX);
end.

